============
Installation
============

At the command line::

    $ pip install networking-h3c

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv networking-h3c
    $ pip install networking-h3c
